@@ -15,19 +15,17 @@ require dirname(__FILE__).'/../inc/admin/prepend.php';
 dcPage::check('usage,contentadmin');
 
 $q = !empty($_GET['q']) ? $_GET['q'] : null;
+$plugin_id = !empty($_GET['plugin_id']) ? html::sanitizeURL($_GET['plugin_id']) : '';
 
 $page = !empty($_GET['page']) ? max(1,(integer) $_GET['page']) : 1;
 $nb_per_page =  10;
 
+$type = !empty($_GET['type']) ? $_GET['type'] : null;
+
 $post_types = $core->getPostTypes();
 foreach ($post_types as $k => $v) {
  	$type_combo[__($k)] = (string) $k;
 }
-$type = !empty($_POST['type']) ? $_POST['type'] : null;
-if (!$type && $q) {
-	// Cope with search form
-	$type = !empty($_GET['type']) ? $_GET['type'] : null;
-}
 if (!in_array($type, $type_combo)) {
 	$type = null;
 }
@@ -47,19 +45,19 @@ if ($type) {
 
 dcPage::openPopup(__('Add a link to an entry'),
 	dcPage::jsLoad('js/_posts_list.js').
-	dcPage::jsLoad('js/jsToolBar/popup_posts.js'));
+	$core->callBehavior('adminPopupPosts', $plugin_id));
 
 echo '<h2 class="page-title">'.__('Add a link to an entry').'</h2>';
 
-echo '<form action="popup_posts.php" method="post">'.
-	'<p><label for"type" class="classic">'.__('Entry type:').'</label> '.form::combo('type',$type_combo,$type).''.
-	$core->formNonce().'</p>'.
+echo '<form action="popup_posts.php" method="get">'.
+	'<p><label for="type" class="classic">'.__('Entry type:').'</label> '.form::combo('type',$type_combo,$type).''.
 	'<noscript><div><input type="submit" value="'.__('Ok').'" /></div></noscript>'.
 	'</form>';
 
 echo '<form action="popup_posts.php" method="get">'.
 	'<p><label for="q" class="classic">'.__('Search entry:').'</label> '.form::field('q',30,255,html::escapeHTML($q)).
 	' <input type="submit" value="'.__('Search').'" />'.
+	form::hidden('plugin_id',html::escapeHTML($plugin_id)).
 	form::hidden('type',html::escapeHTML($type)).
 	'</p></form>';
 
