@@ -32,11 +32,17 @@
 # Nicolas Chachereau
 # Jérôme Lipowicz
 #
-# Version : 3.2.7
-# Release date : 2013-02-11
+# Version : 3.2.9
+# Release date : 2013-12-24
 
 # History :
 #
+# 3.2.9
+# 			=> <a name="anchor"></a> est remplacé par <a id="anchor"></a> pour assurer la compatibilité avec HTML5
+#
+# 3.2.8
+# 			=> <acronym> est remplacé par <abbr> pour assurer la compatibilité avec HTML5
+#
 # 3.2.7
 #			=> Les styles d'alignement des images sont modifiables via les options
 #
@@ -126,7 +132,7 @@
 
 class wiki2xhtml
 {
-	public $__version__ = '3.2.7';
+	public $__version__ = '3.2.8';
 
 	public $T;
 	public $opt;
@@ -350,7 +356,7 @@ class wiki2xhtml
 		$tags = array(
 			'em' => array("''","''"),
 			'strong' => array('__','__'),
-			'acronym' => array('??','??'),
+			'abbr' => array('??','??'),
 			'a' => array('[',']'),
 			'img' => array('((','))'),
 			'q' => array('{{','}}'),
@@ -396,7 +402,7 @@ class wiki2xhtml
 			unset($this->tags['code']);
 		}
 		if (!$this->getOpt('active_acronym')) {
-			unset($this->tags['acronym']);
+			unset($this->tags['abbr']);
 		}
 		if (!$this->getOpt('active_ins')) {
 			unset($this->tags['ins']);
@@ -790,7 +796,7 @@ class wiki2xhtml
 							$type = 'close';
 							$res = $this->__parseImg($res,$attr);
 							break;
-						case 'acronym':
+						case 'abbr':
 							$res = $this->__parseAcronym($res,$attr);
 							break;
 						case 'q':
@@ -854,7 +860,7 @@ class wiki2xhtml
 
 	function __parseLink($str,&$tag,&$attr,&$type)
 	{
-		$n_str = $this->__inlineWalk($str,array('acronym','img'));
+		$n_str = $this->__inlineWalk($str,array('abbr','img','em','strong'));
 		$data = $this->__splitTagsAttr($n_str);
 		$no_image = false;
 
@@ -994,7 +1000,7 @@ class wiki2xhtml
 		$name = $this->protectAttr($str,true);
 
 		if ($name != '') {
-			$attr = ' name="'.$name.'"';
+			$attr = ' id="'.$name.'"';
 		}
 		return null;
 	}
@@ -1313,5 +1319,3 @@ class wiki2xhtml
 	}
 	//*/
 }
-
-?>
