@@ -33,6 +33,8 @@ $GLOBALS['__l10n']['Tags for posts'] = 'Mots-clés pour les billets';
 $GLOBALS['__l10n']['Theme Editor'] = 'Éditeur de thème';
 $GLOBALS['__l10n']['Manage every user preference directive'] = 'Gestion des préférences utilisateur';
 $GLOBALS['__l10n']['Widgets for your blog sidebars'] = 'Widgets pour les volets de votre blog';
+$GLOBALS['__l10n']['dotclear legacy editor'] = 'éditeur historique de Dotclear';
+$GLOBALS['__l10n']['dotclear CKEditor integration'] = 'éditeur CKEditor pour Dotclear';
 $GLOBALS['__l10n']['Search engine form'] = 'Formulaire de recherche';
 $GLOBALS['__l10n']['List of navigation links'] = 'Liste des liens de navigation';
 $GLOBALS['__l10n']['List of selected entries'] = 'Liste des billets sélectionnés';
@@ -146,6 +148,7 @@ $GLOBALS['__l10n']['Home page only'] = 'En page d\'accueil seulement';
 $GLOBALS['__l10n']['Except on home page'] = 'Sauf en page d\'accueil';
 $GLOBALS['__l10n']['Content only'] = 'Contenu seul (sans boîte englobante)';
 $GLOBALS['__l10n']['CSS class:'] = 'Classe CSS supplémentaire pour la boîte englobante :';
+$GLOBALS['__l10n']['Offline'] = 'Hors ligne';
 $GLOBALS['__l10n']['You must provide a link title'] = 'Vous devez fournir un titre de lien';
 $GLOBALS['__l10n']['You must provide a link URL'] = 'Vous devez fournir une URL de lien';
 $GLOBALS['__l10n']['You need to provide a XBEL or OPML file.'] = 'Vous devez fournir un fichier XBEL ou OPML.';
@@ -275,14 +278,39 @@ $GLOBALS['__l10n']['Configuration import / export'] = 'Configuration de l\'impor
 $GLOBALS['__l10n']['You can share your configuration using the following code. To apply a configuration, paste the code, click on "Apply code" and save.'] = 'Vous pouvez partager votre configuration en utilisant le code suivant. Pour appliquer une configuration, copiez le code, cliquez sur « Appliquer le code », puis sauvegardez.';
 $GLOBALS['__l10n']['Copy this code:'] = 'Copier ce code :';
 $GLOBALS['__l10n']['default'] = 'défaut';
-$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = 'Le répertoire ‘public’ n\'existe pas.';
-$GLOBALS['__l10n']['The \'%s\' directory cannot be modified.'] = 'Le répertoire ‘%s’ ne peut être modifié.';
 $GLOBALS['__l10n']['Unable to create css file.'] = 'Impossible de créer le fichier css.';
-$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = 'Au moins une des fonctions suivantes n\'est pas disponible : imagecreatetruecolor, imagepng et imagecreatefrompng.';
-$GLOBALS['__l10n']['Unable to create images.'] = 'Impossible de créer des images.';
-$GLOBALS['__l10n']['Invalid file type.'] = 'Type de fichier invalide.';
-$GLOBALS['__l10n']['Uploaded image is not 800 pixels wide.'] = 'L\'image soumise ne fait pas 800 pixels de large.';
 $GLOBALS['__l10n']['Unable to open image.'] = 'Impossible d\'ouvrir l\'image.';
+$GLOBALS['__l10n']['The configuration has been updated.'] = 'La configuration a été enregistrée.';
+$GLOBALS['__l10n']['Media chooser'] = 'Sélecteur de média';
+$GLOBALS['__l10n']['Link to an entry'] = 'Lien vers une entrée';
+$GLOBALS['__l10n']['Link'] = 'Lien';
+$GLOBALS['__l10n']['visual'] = 'visuel';
+$GLOBALS['__l10n']['source'] = 'source';
+$GLOBALS['__l10n']['You can use the following shortcuts to format your text.'] = 'Vous pouvez utiliser les raccourcis suivants pour formater votre texte.';
+$GLOBALS['__l10n']['-- none --'] = '-- aucun --';
+$GLOBALS['__l10n']['-- block format --'] = '-- format de bloc --';
+$GLOBALS['__l10n']['Paragraph'] = 'Paragraphe';
+$GLOBALS['__l10n']['Level 1 header'] = 'Entête de niveau 1';
+$GLOBALS['__l10n']['Level 2 header'] = 'Entête de niveau 2';
+$GLOBALS['__l10n']['Level 3 header'] = 'Entête de niveau 3';
+$GLOBALS['__l10n']['Level 4 header'] = 'Entête de niveau 4';
+$GLOBALS['__l10n']['Level 5 header'] = 'Entête de niveau 5';
+$GLOBALS['__l10n']['Level 6 header'] = 'Entête de niveau 6';
+$GLOBALS['__l10n']['Strong emphasis'] = 'Emphase forte';
+$GLOBALS['__l10n']['Emphasis'] = 'Emphase';
+$GLOBALS['__l10n']['Inserted'] = 'Inséré';
+$GLOBALS['__l10n']['Deleted'] = 'Supprimé';
+$GLOBALS['__l10n']['Inline quote'] = 'Citation en ligne';
+$GLOBALS['__l10n']['Code'] = 'Code';
+$GLOBALS['__l10n']['Line break'] = 'Retour à la ligne';
+$GLOBALS['__l10n']['Blockquote'] = 'Bloc de citation';
+$GLOBALS['__l10n']['Preformated text'] = 'Texte préformaté';
+$GLOBALS['__l10n']['Unordered list'] = 'Liste non ordonnée';
+$GLOBALS['__l10n']['Ordered list'] = 'Liste ordonnée';
+$GLOBALS['__l10n']['URL?'] = 'URL ?';
+$GLOBALS['__l10n']['Language?'] = 'Langue ?';
+$GLOBALS['__l10n']['External image'] = 'Image externe';
+$GLOBALS['__l10n']['Remove text formating'] = 'Retirer le formatage du texte';
 $GLOBALS['__l10n']['Checks trackback source for a link to the post'] = 'Contrôle si la source du rétrolien comporte un lien vers le billet';
 $GLOBALS['__l10n']['Import/Export'] = 'Import/Export';
 $GLOBALS['__l10n']['Flat file export'] = 'Fichier d\'exportation « à plat »';
@@ -502,6 +530,7 @@ $GLOBALS['__l10n']['Archive'] = 'Archive';
 $GLOBALS['__l10n']['Page'] = 'Page';
 $GLOBALS['__l10n']['Tags'] = 'Mots-clés';
 $GLOBALS['__l10n']['User defined'] = 'Saisie libre';
+$GLOBALS['__l10n']['Configuration successfully updated.'] = 'La configuration a été mise à jour';
 $GLOBALS['__l10n']['Label'] = 'Libellé';
 $GLOBALS['__l10n']['Recent posts'] = 'Billets récents';
 $GLOBALS['__l10n']['Switch to %s language'] = 'Basculer vers le %s';
@@ -532,6 +561,8 @@ $GLOBALS['__l10n']['Label of item menu:'] = 'Libellé de l\'item de menu :';
 $GLOBALS['__l10n']['Description of item menu:'] = 'Description de l\'item de menu :';
 $GLOBALS['__l10n']['URL of item menu:'] = 'URL de l\'item de menu :';
 $GLOBALS['__l10n']['Add this item'] = 'Ajouter cet item';
+$GLOBALS['__l10n']['Enable simple menu for this blog'] = 'Activer le menu simple pour ce blog';
+$GLOBALS['__l10n']['Save configuration'] = 'Enregistrer la configuration';
 $GLOBALS['__l10n']['Add an item'] = 'Ajouter un item de menu';
 $GLOBALS['__l10n']['Menu items list'] = 'Liste des items de menu';
 $GLOBALS['__l10n']['Update menu'] = 'Mettre à jour le menu';
@@ -578,17 +609,24 @@ $GLOBALS['__l10n']['No tags on this blog.'] = 'Aucun mot-clé sur ce blog.';
 $GLOBALS['__l10n']['Edit theme files'] = 'Modifier les fichiers du thème';
 $GLOBALS['__l10n']['Syntax highlighting in theme editor'] = 'Coloration syntaxique de l\'éditeur de thème';
 $GLOBALS['__l10n']['No file'] = 'Aucun fichier';
+$GLOBALS['__l10n']['From theme:'] = 'Du thème :';
+$GLOBALS['__l10n']['From parent:'] = 'Du thème parent :';
+$GLOBALS['__l10n']['From template set:'] = 'Du jeu de template :';
 $GLOBALS['__l10n']['File does not exist.'] = 'Ce fichier n\'existe pas.';
 $GLOBALS['__l10n']['File %s is not readable'] = 'Le fichier %s n\'est pas lisible';
 $GLOBALS['__l10n']['Unable to write file %s. Please check your theme files and folders permissions.'] = 'Impossible d\'écrire le fichier %s. Contrôlez les permissions des fichiers et des répertoires de votre thème.';
+$GLOBALS['__l10n']['Unable to delete file %s. Please check your theme files and folders permissions.'] = 'Impossible de supprimer le fichier %s. Contrôlez les permissions des fichiers et des répertoires de votre thème.';
+$GLOBALS['__l10n']['The file has been reset.'] = 'Le fichier a été réinitialisé.';
 $GLOBALS['__l10n']['Saving document...'] = 'Enregistrement du document…';
 $GLOBALS['__l10n']['Document saved'] = 'Document enregistré';
 $GLOBALS['__l10n']['An error occurred:'] = 'Une erreur est survenue :';
+$GLOBALS['__l10n']['Are you sure you want to reset this file?'] = 'Êtes-vous sûr de vouloir réinitialiser ce fichier ?';
 $GLOBALS['__l10n']['Your current theme on this blog is "%s".'] = 'Actuellement votre thème sur ce blog est « %s ».';
 $GLOBALS['__l10n']['You can\'t edit default theme.'] = 'Vous ne pouvez pas modifier le thème par défaut.';
 $GLOBALS['__l10n']['Please select a file to edit.'] = 'Sélectionnez un fichier à modifier.';
 $GLOBALS['__l10n']['File editor'] = 'Éditeur de fichier';
 $GLOBALS['__l10n']['Editing file %s'] = 'Édition du fichier %s';
+$GLOBALS['__l10n']['Reset'] = 'Réinitialiser';
 $GLOBALS['__l10n']['This file is not writable. Please check your theme files permissions.'] = 'Ce fichier n\'est pas modifiable. Contrôlez les permissions de vos fichiers de thème.';
 $GLOBALS['__l10n']['Templates files'] = 'Fichiers du thème';
 $GLOBALS['__l10n']['CSS files'] = 'Fichiers CSS';
