@@ -11,6 +11,8 @@
 # -- END LICENSE BLOCK -----------------------------------------
 if (!defined('DC_CONTEXT_ADMIN')) { return; }
 
-$_menu['System']->addItem('about:config','plugin.php?p=aboutConfig','index.php?pf=aboutConfig/icon.png',
-		preg_match('/plugin.php\?p=aboutConfig(&.*)?$/',$_SERVER['REQUEST_URI']),
-		$core->auth->isSuperAdmin());
+$_menu['System']->addItem('about:config',
+	$core->adminurl->get('admin.plugin.aboutConfig'),
+	dcPage::getPF('aboutConfig/icon.png'),
+	preg_match('/'.preg_quote($core->adminurl->get('admin.plugin.aboutConfig')).'(&.*)?$/',$_SERVER['REQUEST_URI']),
+	$core->auth->isSuperAdmin());
