@@ -78,10 +78,12 @@ class urlPages extends dcUrlHandlers
 					}
 
 					# Check for match
+					# Note: We must prefix post_id key with '#'' in pwd_cookie array in order to avoid integer conversion
+					# because MyArray["12345"] is treated as MyArray[12345]
 					if ((!empty($_POST['password']) && $_POST['password'] == $post_password)
-					|| (isset($pwd_cookie[$post_id]) && $pwd_cookie[$post_id] == $post_password))
+					|| (isset($pwd_cookie['#'.$post_id]) && $pwd_cookie['#'.$post_id] == $post_password))
 					{
-						$pwd_cookie[$post_id] = $post_password;
+						$pwd_cookie['#'.$post_id] = $post_password;
 						setcookie('dc_passwd',json_encode($pwd_cookie),0,'/');
 					}
 					else
@@ -116,12 +118,18 @@ class urlPages extends dcUrlHandlers
 
 					if ($content != '')
 					{
-						if ($core->blog->settings->system->wiki_comments) {
-							$core->initWikiComment();
+						# --BEHAVIOR-- publicBeforeCommentTransform
+						$buffer = $core->callBehavior('publicBeforeCommentTransform',$content);
+						if ($buffer != '') {
+							$content = $buffer;
 						} else {
-							$core->initWikiSimpleComment();
+							if ($core->blog->settings->system->wiki_comments) {
+								$core->initWikiComment();
+							} else {
+								$core->initWikiSimpleComment();
+							}
+							$content = $core->wikiTransform($content);
 						}
-						$content = $core->wikiTransform($content);
 						$content = $core->HTMLfilter($content);
 					}
 
@@ -188,7 +196,13 @@ class urlPages extends dcUrlHandlers
 				if ($_ctx->posts->trackbacksActive()) {
 					header('X-Pingback: '.$core->blog->url.$core->url->getURLFor("xmlrpc",$core->blog->id));
 				}
-				$core->tpl->setPath($core->tpl->getPath(), dirname(__FILE__).'/default-templates');
+
+				$tplset = $core->themes->moduleInfo($core->blog->settings->system->theme,'tplset');
+				if (!empty($tplset) && is_dir(dirname(__FILE__).'/default-templates/'.$tplset)) {
+					$core->tpl->setPath($core->tpl->getPath(), dirname(__FILE__).'/default-templates/'.$tplset);
+				} else {
+					$core->tpl->setPath($core->tpl->getPath(), dirname(__FILE__).'/default-templates/'.DC_DEFAULT_TPLSET);
+				}
 				self::serveDocument('page.html');
 			}
 		}
@@ -215,6 +229,10 @@ class urlPages extends dcUrlHandlers
 			else
 			{
 				$_ctx->preview = true;
+				if (defined ("DC_ADMIN_URL")) {
+					$_ctx->xframeoption=DC_ADMIN_URL;
+				}
+
 				self::pages($post_url);
 			}
 		}
@@ -228,6 +246,9 @@ class tplPages
 	{
 		global $core, $_ctx;
 
+		if ($w->offline)
+			return;
+
 		if (($w->homeonly == 1 && $core->url->type != 'default') ||
 			($w->homeonly == 2 && $core->url->type == 'default')) {
 			return;
@@ -255,10 +276,7 @@ class tplPages
 			return;
 		}
 
-		$res =
-		($w->content_only ? '' : '<div class="pages'.($w->class ? ' '.html::escapeHTML($w->class) : '').'">').
-		($w->title ? '<h2>'.html::escapeHTML($w->title).'</h2>' : '').
-		'<ul>';
+		$res = ($w->title ? $w->renderTitle(html::escapeHTML($w->title)) : '').'<ul>';
 
 		while ($rs->fetch()) {
 			$class = '';
@@ -269,8 +287,8 @@ class tplPages
 			html::escapeHTML($rs->post_title).'</a></li>';
 		}
 
-		$res .= '</ul>'.($w->content_only ? '' : '</div>');
+		$res .= '</ul>';
 
-		return $res;
+		return $w->renderDiv($w->content_only,'pages '.$w->class,'',$res);
 	}
 }
