@@ -51,6 +51,14 @@ try
 		$file['c'] = $_POST['file_content'];
 		$o->writeFile($file['type'],$file['f'],$file['c']);
 	}
+
+	# Delete file
+	if (!empty($_POST['delete']))
+	{
+		$o->deleteFile($file['type'],$file['f']);
+		dcPage::addSuccessNotice(__('The file has been reset.'));
+		http::redirect($p_url.'&'.$file['type'].'='.$file['f']);
+	}
 }
 catch (Exception $e)
 {
@@ -61,26 +69,28 @@ catch (Exception $e)
 <html>
 <head>
   <title><?php echo __('Edit theme files'); ?></title>
-  <link rel="stylesheet" type="text/css" href="index.php?pf=themeEditor/style.css" />
+  <link rel="stylesheet" type="text/css" href="<?php echo dcPage::getPF('themeEditor/style.css'); ?>" />
   <script type="text/javascript">
   //<![CDATA[
   <?php echo dcPage::jsVar('dotclear.msg.saving_document',__("Saving document...")); ?>
   <?php echo dcPage::jsVar('dotclear.msg.document_saved',__("Document saved")); ?>
   <?php echo dcPage::jsVar('dotclear.msg.error_occurred',__("An error occurred:")); ?>
+  <?php echo dcPage::jsVar('dotclear.msg.confirm_reset_file',__("Are you sure you want to reset this file?")); ?>
   <?php echo dcPage::jsVar('dotclear.colorsyntax',$user_ui_colorsyntax); ?>
   //]]>
   </script>
-  <script type="text/javascript" src="index.php?pf=themeEditor/script.js"></script>
+  <?php echo dcPage::jsConfirmClose('file-form'); ?>
+  <script type="text/javascript" src="<?php echo dcPage::getPF('themeEditor/script.js'); ?>"></script>
 <?php if ($user_ui_colorsyntax) { ?>
-  <link rel="stylesheet" type="text/css" href="index.php?pf=themeEditor/codemirror/codemirror.css" />
-  <link rel="stylesheet" type="text/css" href="index.php?pf=themeEditor/codemirror.css" />
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/codemirror.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/multiplex.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/xml.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/javascript.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/css.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/php.js"></script>
-  <script type="text/JavaScript" src="index.php?pf=themeEditor/codemirror/htmlmixed.js"></script>
+  <link rel="stylesheet" type="text/css" href="<?php echo dcPage::getPF( 'themeEditor/codemirror/codemirror.css'); ?>" />
+  <link rel="stylesheet" type="text/css" href="<?php echo dcPage::getPF( 'themeEditor/codemirror.css'); ?>" />
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/codemirror.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/multiplex.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/xml.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/javascript.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/css.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/php.js'); ?>"></script>
+  <script type="text/JavaScript" src="<?php echo dcPage::getPF('themeEditor/codemirror/htmlmixed.js'); ?>"></script>
 <?php } ?>
 </head>
 
@@ -89,7 +99,7 @@ catch (Exception $e)
 echo dcPage::breadcrumb(
 	array(
 		html::escapeHTML($core->blog->name) => '',
-		__('Blog appearance') => 'blog_theme.php',
+		__('Blog appearance') => $core->adminurl->get('admin.blog.theme'),
 		__('Edit theme files') => ''
 	)).
 	dcPage::notices();
@@ -121,6 +131,7 @@ else
 	{
 		echo
 		'<p><input type="submit" name="write" value="'.__('Save').' (s)" accesskey="s" /> '.
+		($o->deletableFile($file['type'],$file['f']) ? '<input type="submit" name="delete" class="delete" value="'.__('Reset').'" />' : '').
 		$core->formNonce().
 		($file['type'] ? form::hidden(array($file['type']),$file['f']) : '').
 		'</p>';
